#' Various useful functions for statisticians: describe data, plot Kaplan-Meier curves with numbers of subjects at risk, compare data sets, display spaghetti-plot, build multi-contingency tables...
#' @title A few useful functions for statisticians
#' @author Hugo Varet
#' @name packHV-package
"_PACKAGE"
